/*******************************************************************************
*
*                    ATmega32 Timer1 Phase correct PWM
*                    ---------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   10.10.2014
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*
*   Clock source:           - Any 8Mhz clock
*
*   Recommended             - High: 0x99
*   Fuse settings:          - Low:  0xC4
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA32     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |                   |
*          GND ---->|GND                |
*                   |                   |
*                   |               PA0 |----> DOUT   
*                   |               PA1 |----> DOUT   
*                   |        PD5 (OC1A) |----> DOUT     
*                   |                   |
*
*******************************************************************************/
#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{

    DDRD = 0x20;                         // Setup PD5 as output
    DDRA = 0x03;                         // Setup PA0 and PA1 as output

    ICR1 = 1000;                         // Set TOP to 10000
    OCR1A = 100;                         // Set Dutycycle to 10%

	
	
    TCCR1A = (1<<WGM11)|(1<<COM1A1);     // Set Timer1 in Phase Correct Mode  
	                                     // with ICR1 as TOP value. Set OC1A
    TCCR1B = (1<<WGM13)|(1<<CS10);       // on compare match and clear OC1A 
	                                     // on BOTTOM. Clock Prescaler is 1024
			  
			  
    TIMSK |= (1<<TOIE1) | (1<<OCIE1A);   // Enable Timer 1 Overflow
	                                     // and Compare interrupt
    sei();                               // Set the I-bit in SREG

    for(;;);                             // Endless loop
                                         // main() will never be left

    return 0;                            // This line will never be executed
}

// Interrupt subroutine timer 1 overflow
 ISR(TIMER1_OVF_vect)
{
     PORTA ^= 0x01;                       // Toggle PA0
     PORTA ^= 0x01;                       // Toggle PA0
}

// Interrupt subroutine timer 1 compare A match
 ISR(TIMER1_COMPA_vect)
{
     PORTA ^= 0x02;                       // Toggle PA1
     PORTA ^= 0x02;                       // Toggle PA1
}
